==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QIntValidator_shell.h <==
#ifndef QINTVALIDATOR_SHELL_H
#define QINTVALIDATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtGui/qvalidator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QIntValidator_shell : public QIntValidator, public QtJambiShellInterface
{
public:
    QIntValidator_shell(QObject* parent0 = nullptr);
    QIntValidator_shell(int bottom0, int top1, QObject* parent2 = nullptr);
    ~QIntValidator_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fixup(QString& input0) const override;
    void setRange(int bottom0, int top1) override;
    void timerEvent(QTimerEvent* event0) override;
    QValidator::State validate(QString& arg__1, int& arg__2) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QIntValidator_access : public QIntValidator
{
    void __qt_fixup_ref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject input0) const;
    void __qt_setRange_int_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint bottom0, jint top1);
    jint __qt_validate_ref_QString_ref_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1) const;
};

#endif // QINTVALIDATOR_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QIntValidator_shell.h <==
#ifndef QINTVALIDATOR_SHELL_H
#define QINTVALIDATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qvalidator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QIntValidator_shell : public QIntValidator, public QtJambiShellInterface
{
public:
    QIntValidator_shell(QObject* parent0 = nullptr);
    QIntValidator_shell(int bottom0, int top1, QObject* parent2 = nullptr);
    ~QIntValidator_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QIntValidator_mshell;
    friend class QIntValidator_oshell;
};


class QIntValidator_mshell : public QIntValidator_shell
{
public:
    using QIntValidator_shell::QIntValidator_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QIntValidator_oshell : public QIntValidator_mshell
{
public:
    using QIntValidator_mshell::QIntValidator_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fixup(QString& input0) const override;
    void timerEvent(QTimerEvent* event0) override;
    QValidator::State validate(QString& arg__1, int& arg__2) const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QIntValidator_access : public QIntValidator
{
    void __qt_fixup_ref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject input0) const;
    jint __qt_validate_ref_QString_ref_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject arg__1) const;
};

#endif // QINTVALIDATOR_SHELL_H
